'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var core = require('@edtr-io/core');
var editorUi = require('@edtr-io/editor-ui');
var rendererUi = require('@edtr-io/renderer-ui');
var React = require('react');
var SyntaxHighlight = _interopDefault(require('react-syntax-highlighter'));

function HighlightRenderer(_ref) {
  var state = _ref.state;
  return React.createElement(SyntaxHighlight, {
    language: state.language.value,
    showLineNumbers: state.lineNumbers.value
  }, state.text.value || 'Switch into edit mode then paste your sourcecode here...');
}

var QuestionIcon =
/*#__PURE__*/
editorUi.styled(editorUi.Icon)({
  color: 'black',
  margin: '0 10px -3px 5px',
  '&:hover': {
    color: 'rgba(0,0,0,0.5)'
  }
});
var CheckboxContainer =
/*#__PURE__*/
editorUi.styled.div({
  "float": 'right'
}); // TODO: type and theming. maybe put in editor-ui?

var HelpIcon = function HelpIcon() {
  return React.createElement("a", {
    href: "https://github.com/conorhastings/react-syntax-highlighter/blob/master/AVAILABLE_LANGUAGES_HLJS.MD",
    rel: "noopener noreferrer",
    target: "_blank",
    title: "Available Languages"
  }, React.createElement(QuestionIcon, {
    icon: editorUi.faQuestionCircle
  }));
};

var HighlightEditor = function HighlightEditor(props) {
  var state = props.state,
      focused = props.focused,
      editable = props.editable;
  var edit = focused && editable;

  var _React$useState = React.useState(edit),
      throttledEdit = _React$useState[0],
      setEditThrotteled = _React$useState[1];

  if (edit != throttledEdit) {
    if (!edit) {
      setTimeout(function () {
        setEditThrotteled(false);
      }, 500);
    } else {
      setEditThrotteled(true);
    }
  }

  return throttledEdit || edit ? React.createElement(React.Fragment, null, React.createElement(rendererUi.EditorTextarea, {
    value: state.text.value,
    name: "text",
    placeholder: "Write some code here. Preview will be shown when you leave the area",
    onChange: function onChange(e) {
      state.text.set(e.target.value);
    }
  }, state.text.value), React.createElement(editorUi.PrimarySettings, null, React.createElement(editorUi.EditorInput, {
    label: "Language:",
    value: state.language.value,
    onChange: function onChange(e) {
      state.language.set(e.target.value);
    },
    placeholder: "enter Language"
  }), React.createElement(HelpIcon, null), React.createElement(CheckboxContainer, null, React.createElement(editorUi.EditorCheckbox, {
    label: "Show Line Numbers",
    onChange: function onChange() {
      state.lineNumbers.set(!state.lineNumbers.value);
    },
    checked: state.lineNumbers.value
  })))) : React.createElement(HighlightRenderer, Object.assign({}, props));
};

var highlightState =
/*#__PURE__*/
core.StateType.object({
  text:
  /*#__PURE__*/
  core.StateType.string(''),
  language:
  /*#__PURE__*/
  core.StateType.string('text'),
  lineNumbers:
  /*#__PURE__*/
  core.StateType["boolean"](false)
});
var highlightPlugin = {
  Component: HighlightEditor,
  state: highlightState,
  title: 'Code',
  description: 'Schreibe Code und lasse ihn je nach Programmiersprache highlighten.',
  icon:
  /*#__PURE__*/
  editorUi.createIcon(editorUi.faCode)
};

exports.highlightPlugin = highlightPlugin;
exports.highlightState = highlightState;
//# sourceMappingURL=plugin-highlight.cjs.development.js.map
